summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmspheresweepedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmspheresweepedit.h')
-rw-r--r--kpovmodeler/pmspheresweepedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmspheresweepedit.h b/kpovmodeler/pmspheresweepedit.h
index c6b8a9f1..753ccb12 100644
--- a/kpovmodeler/pmspheresweepedit.h
+++ b/kpovmodeler/pmspheresweepedit.h
@@ -48,9 +48,9 @@ class PMSphereSweepEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSphereSweepEdit with tqparent and name
*/
- PMSphereSweepEdit( TQWidget* tqparent, const char* name = 0 );
+ PMSphereSweepEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -48,9 +48,9 @@ class PMSphereSweepEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMSphereSweepEdit with tqparent and name
+ * Creates a PMSphereSweepEdit with parent and name
*/